-- =============================================
-- SaveToDB Framework for Microsoft SQL Server Compact
-- Version 7.19, March 12, 2018
--
-- Copyright 2013-2018 Gartle Technology Corporation
-- =============================================

CREATE TABLE [QueryList] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_TYPE] [nvarchar](128) NOT NULL,
    [TABLE_CODE] [ntext],
    [INSERT_PROCEDURE] [ntext],
    [UPDATE_PROCEDURE] [ntext],
    [DELETE_PROCEDURE] [ntext],
    [PROCEDURE_TYPE] [nvarchar](128),
  CONSTRAINT [PK_QueryList] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [QueryList_TableName]
    ON [QueryList] (
    [TABLE_NAME]
);
GO
-- print QueryList has been created

CREATE TABLE [EventHandlers] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [COLUMN_NAME] [nvarchar](128),
    [EVENT_NAME] [nvarchar](50) NOT NULL,
    [HANDLER_SCHEMA] [nvarchar](128),
    [HANDLER_NAME] [nvarchar](128),
    [HANDLER_TYPE] [nvarchar](60),
    [HANDLER_CODE] [ntext],
    [TARGET_WORKSHEET] [nvarchar](255),
    [MENU_ORDER] [int],
    [EDIT_PARAMETERS] [bit],
  CONSTRAINT [PK_EventHandlers] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [EventHandlers_TableName_ColumnName_EventName_HandlerName]
    ON [EventHandlers] (
    [TABLE_NAME], 
    [COLUMN_NAME], 
    [EVENT_NAME], 
    [HANDLER_NAME]
);
GO
-- print EventHandlers has been created

CREATE TABLE [ParameterValues] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [PARAMETER_NAME] [nvarchar](128) NOT NULL,
    [SELECT_SCHEMA] [nvarchar](128),
    [SELECT_NAME] [nvarchar](128) NOT NULL,
    [SELECT_TYPE] [nvarchar](128),
    [SELECT_CODE] [ntext],
  CONSTRAINT [PK_ParameterValues] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [ParameterValues_SpecificName_ParameterName]
    ON [ParameterValues] (
    [TABLE_NAME],
    [PARAMETER_NAME]
);
GO
-- print ParameterValues has been created

CREATE TABLE [ObjectTranslation] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [nchar](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](255),
    [TRANSLATED_COMMENT] [nvarchar](4000),
  CONSTRAINT [PK_ObjectTranslation] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [IX_ObjectTranslation_TableName_LanguageName]
    ON [ObjectTranslation] (
    [TABLE_NAME],
    [LANGUAGE_NAME]
);
GO
-- print ObjectTranslation has been created

CREATE TABLE [ColumnTranslation] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128),
    [COLUMN_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [nchar](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](1024),
  CONSTRAINT [PK_ColumnTranslation] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [ColumnTranslation_TableName_ColumnName_Language]
    ON [ColumnTranslation] (
    [TABLE_NAME],
    [COLUMN_NAME],
    [LANGUAGE_NAME]
);
GO
-- print ColumnTranslation has been created

CREATE TABLE [TableFormats] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_EXCEL_FORMAT_XML] [ntext],
  CONSTRAINT [PK_TableFormat] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [TableFormats_TableName]
    ON [TableFormats] (
    [TABLE_NAME]
);
GO
-- print TableFormats has been created

INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'ColumnTranslation',NULL,N'Actions',NULL,N'Online Help',N'HTTP',N'http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'ObjectTranslation',NULL,N'Actions',NULL,N'Online Help',N'HTTP',N'http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'EventHandlers',NULL,N'Actions',NULL,N'Online Help',N'HTTP',N'http://www.savetodb.com/savetodb/configuring-event-handlers.htm',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'ParameterValues',NULL,N'Actions',NULL,N'Online Help',N'HTTP',N'http://www.savetodb.com/savetodb/configuring-parameter-values.htm',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'QueryList',NULL,N'Actions',NULL,N'Online Help',N'HTTP',N'http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, N'TableFormats',NULL,N'Actions',NULL,N'Online Help',N'HTTP',N'http://www.savetodb.com/savetodb/configuring-table-formats.htm',NULL,11,NULL);
GO

INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, N'QueryList', N'TABLE_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,CODE,HTTP,TEXT');
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, N'QueryList', N'PROCEDURE_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,CODE,MERGE');
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, N'EventHandlers', N'EVENT_NAME', N'ValidationList', NULL, N'', N'VALUES', N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, N'EventHandlers', N'HANDLER_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, N'ParameterValues', N'SELECT_TYPE', N'ValidationList', NULL, N'', N'VALUES', N'TABLE,CODE,HTTP,VALUES,RANGE');
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, N'EventHandlers', N'HANDLER_CODE', N'DoNotConvertFormulas', NULL, N'', NULL, NULL);
GO

INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'ColumnTranslation', N'en', NULL, N'Configuration Table of Column Translation', N'The table defines translation for Excel table headers and ribbon fields');
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'EventHandlers', N'en', NULL, N'Configuration Table of Excel Event Handlers', N'The table defines Excel event handlers and Actions and Context Menu items');
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'ObjectTranslation', N'en', NULL, N'Configuration Table of Object Translation', N'The table defines translation for Query List, Actions and Context Menu items');
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'ParameterValues', N'en', NULL, N'Configuration Table of Parameter Value Queries', N'The table defines objects to select ribbon parameter values');
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'QueryList', N'en', NULL, N'Configuration Table of Query List', N'The table defines configuration of Query List objects');
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'TableFormats', N'en', NULL, N'Configuration Table of Excel Table Formats', N'The table contains Excel formats of database objects');
GO

INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, N'Online Help', N'en', N'Online Help', NULL, NULL);
GO

INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'ID', N'en', NULL, NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'TABLE_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'TABLE_NAME', N'en', NULL, N'Database object name or unique name for SQL-code and http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'TABLE_TYPE', N'en', NULL, N'Database object type, CODE for SQL-code, or HTTP for http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'TABLE_CODE', N'en', NULL, N'SQL-code or http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'INSERT_PROCEDURE', N'en', NULL, N'Destination table to save changes or INSERT SQL-code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'UPDATE_PROCEDURE', N'en', NULL, N'Destination table to save changes or UPDATE SQL-code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'QueryList', N'DELETE_PROCEDURE', N'en', NULL, N'Destination table to save changes or DELETE SQL-code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'ID', N'en', NULL, NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'TABLE_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'TABLE_NAME', N'en', NULL, N'Database object name, SQL-code name, or http-query name');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'COLUMN_NAME', N'en', NULL, N'Column name or NULL to use the handler for entire table');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'EVENT_NAME', N'en', NULL, N'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'HANDLER_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'HANDLER_NAME', N'en', NULL, N'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'HANDLER_TYPE', N'en', NULL, N'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'HANDLER_CODE', N'en', NULL, N'SQL-code or http-query');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'TARGET_WORKSHEET', N'en', NULL, N'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'MENU_ORDER', N'en', NULL, N'Sort order of Actions and Context Menu items');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'EventHandlers', N'EDIT_PARAMETERS', N'en', NULL, N'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'ID', N'en', NULL, NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'TABLE_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'TABLE_NAME', N'en', NULL, N'Database object name');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'PARAMETER_NAME', N'en', NULL, N'Column name');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'SELECT_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'SELECT_NAME', N'en', NULL, N'Database object name or name for SQL-code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'SELECT_TYPE', N'en', NULL, N'Database object type or CODE for SQL-code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ParameterValues', N'SELECT_CODE', N'en', NULL, N'SQL-code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'ID', N'en', NULL, NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'TABLE_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'TABLE_NAME', N'en', NULL, N'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'LANGUAGE_NAME', N'en', NULL, N'Two-char language code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'TRANSLATED_NAME', N'en', NULL, N'Translated name for Query List, Actions and Context Menus');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'TRANSLATED_DESC', N'en', NULL, N'Text for ScreenTips and SaveToDB_Desc named cells');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ObjectTranslation', N'TRANSLATED_COMMENT', N'en', NULL, N'Text for SuperTips and SaveToDB_Comment named cells');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'ID', N'en', NULL, NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'TABLE_SCHEMA', N'en', NULL, N'Not used');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'TABLE_NAME', N'en', NULL, N'Database object name or NULL for entire database scope');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'COLUMN_NAME', N'en', NULL, N'Column name');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'LANGUAGE_NAME', N'en', NULL, N'Two-char language code');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'TRANSLATED_NAME', N'en', NULL, N'Translated name for Excel table headers and ribbon parameters');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, N'ColumnTranslation', N'TRANSLATED_DESC', N'en', NULL, N'Text for Excel table header comments and ribbon parameter SuperTips');
GO

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'QueryList', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".QueryList">
<columnFormats>
<column name="" property="ListObjectName" value="QueryList_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_TYPE" property="Address" value="$F$7" type="String" />
<column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double" />
<column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_TYPE" property="Validation.Formula1" value="TABLE;CODE;HTTP;TEXT" type="String" />
<column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_CODE" property="Address" value="$G$7" type="String" />
<column name="TABLE_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Address" value="$H$7" type="String" />
<column name="INSERT_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Address" value="$I$7" type="String" />
<column name="UPDATE_PROCEDURE" property="ColumnWidth" value="21.71" type="Double" />
<column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Address" value="$J$7" type="String" />
<column name="DELETE_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Address" value="$K$7" type="String" />
<column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.86" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Formula1" value="TABLE;CODE;MERGE" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$9" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$E$7:$E$9" type="String" />
<column name="TABLE_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$9" type="String" />
<column name="TABLE_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="TABLE_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'EventHandlers', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".EventHandlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(60) datatype." type="String" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="65.71" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="255" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$18" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$18" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$18" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'ParameterValues', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".ParameterValues">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PARAMETER_NAME" property="Address" value="$F$7" type="String" />
<column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double" />
<column name="PARAMETER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String" />
<column name="SELECT_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_NAME" property="Address" value="$H$7" type="String" />
<column name="SELECT_NAME" property="ColumnWidth" value="15.29" type="Double" />
<column name="SELECT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_NAME" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_TYPE" property="Address" value="$I$7" type="String" />
<column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double" />
<column name="SELECT_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_TYPE" property="Validation.Formula1" value="CODE;TABLE;VALUES;RANGE" type="String" />
<column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_CODE" property="Address" value="$J$7" type="String" />
<column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$8" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(2).NumberFormat" value="General" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).Priority" value="6" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(2).NumberFormat" value="General" type="String" />
<column name="SELECT_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$8" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'ObjectTranslation', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".ObjectTranslation">
<columnFormats>
<column name="" property="ListObjectName" value="ObjectTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$F$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nchar(2) datatype." type="String" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="43.86" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="255" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_COMMENT" property="ColumnWidth" value="69.71" type="Double" />
<column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Formula1" value="4000" type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(4000) datatype." type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$16" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$16" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$F$7:$F$16" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Priority" value="3" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'ColumnTranslation', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".ColumnTranslation">
<columnFormats>
<column name="" property="ListObjectName" value="ColumnTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="22.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$G$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nchar(2) datatype." type="String" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="70.71" type="Double" />
<column name="TRANSLATED_DESC" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="1024" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(1024) datatype." type="String" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$55" type="String" />
<column name="COLUMN_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="COLUMN_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$55" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$G$7:$G$55" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Priority" value="3" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'TableFormats', N'<?xml version="1.0" encoding="Unicode"?>
<table name="TableFormats">
<columnFormats>
<column name="" property="ListObjectName" value="UserObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="_RowNum" property="WrapText" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="WrapText" value="True" type="Boolean" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="WrapText" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="WrapText" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_EXCEL_FORMAT_XML" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_EXCEL_FORMAT_XML" property="Address" value="$F$7" type="String" />
<column name="TABLE_EXCEL_FORMAT_XML" property="ColumnWidth" value="101.86" type="Double" />
<column name="TABLE_EXCEL_FORMAT_XML" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$11" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.Zoom" value="100" type="Double" />
</columnFormats>
</table>');
GO

-- print SaveToDB Framework data have been added

-- print SaveToDB Framework has been installed
